/*

*/

package server;

import java.util.Properties;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileInputStream;
import java.io.IOException;

/**
   This class instantiates and runs an instance of the HttpApplicationServer
   framework using the HttpServerMethods implementation of the HttpMethods
   interface. Running this program brings up a static HTTP server that
   supports most of the HTTP methods (GET, HEAD, POST, PUT, OPTIONS).
*/
public class HttpServer
{
   private static final int SERVER_PORT = 8080; // Should be above 1023.
   private static final String SERVER_ROOT = "public_html";

   /**
      The main() method configures the server using
      the httpserver.properties file and command-line
      arguments.
   */
   public static void main(String[] args)
   {
      String serverRoot = SERVER_ROOT; // default value
      int portNumber = SERVER_PORT;    // default value

      final Properties properties = new Properties();
      try( FileInputStream fis =
             new FileInputStream(
                new File("httpserver.properties")) )
      {
         properties.load( fis );
         serverRoot = properties.getProperty("root");
         final String port = properties.getProperty("port");
         if (port != null) portNumber = Integer.parseInt(port);
      }
      catch (FileNotFoundException e)
      {
         /* ignore FileNotFoundException */
      }
      catch (IOException e)
      {
         e.printStackTrace(System.out);
         System.exit(-1);
      }

      if (0 < args.length)
      {
         portNumber = Integer.parseInt(args[0]);
      }
      if (1 < args.length)
      {
         serverRoot = args[1];
      }

      // Instantiate and start up an instance of the server.
      new HttpApplicationServer(portNumber,
                                serverRoot,
                                new HttpServerMethods());
   }
}
